agentle.mcp.sampling.messages.text\_message\_content
====================================================

.. automodule:: agentle.mcp.sampling.messages.text_message_content

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      BaseModel
      TextMessageContent
   